@@ -2,54 +2,6 @@
 #include <Rcpp.h>
 using namespace Rcpp;
 
-const int SOILCOM_dZ_m = 0;
-const int SOILCOM_dZUp = 1;
-const int SOILCOM_dZDown = 2;
-const int SOILCOM_lambda = 3;
-const int SOILCOM_theta_micro = 4;
-const int SOILCOM_theta_b = 5;
-const int SOILCOM_theta_macro = 6;
-const int SOILCOM_theta_sat_fict = 7;
-const int SOILCOM_Ksat_b = 8;
-const int SOILCOM_Ksat_b_ms = 9;
-const int SOILCOM_Ksat = 10;
-const int SOILCOM_Ksat_ms = 11;
-const int SOILCOM_Psi = 12;
-const int SOILCOM_K = 13;
-const int SOILCOM_C = 14;
-const int SOILCOM_Psi_m = 15;
-const int SOILCOM_K_ms = 16;
-const int SOILCOM_Kbc = 17;
-const int SOILCOM_Kbc_ms = 18;
-const int SOILCOM_C_m = 19;
-const int SOILCOM_S_macro = 20;
-const int SOILCOM_e_macro = 21;
-const int SOILCOM_Kmacro_ms = 22;
-const int SOILCOM_waterFluidity = 23;
-const int SOILCOM_a = 24;
-const int SOILCOM_b = 25;
-const int SOILCOM_c = 26;
-const int SOILCOM_d = 27;
-const int SOILCOM_e = 28;
-const int SOILCOM_f = 29;
-const int SOILCOM_K_step_ms05 = 30;
-const int SOILCOM_C_step_m05 = 31;
-const int SOILCOM_C_step = 32;
-const int SOILCOM_C_step_m = 33;
-const int SOILCOM_K_step_ms = 34;
-const int SOILCOM_K_step = 35;
-const int SOILCOM_Psi_step = 36;
-const int SOILCOM_Psi_step_m = 37;
-const int SOILCOM_S_macro_step = 38;
-const int SOILCOM_Kmacro_step_ms = 39;
-const int SOILCOM_theta_macro_step = 40;
-const int SOILCOM_theta_micro_step = 41;
-const int SOILCOM_finalSourceSinks_m3s = 42;
-const int SOILCOM_capill_below = 43;
-const int SOILCOM_drain_above = 44;
-const int SOILCOM_drain_below = 45;
-const int SOILCOM_lateral_flows_step_mm = 46;
-
 List communicationLongWaveRadiation(int ncanlayers) {
   NumericVector Lup(ncanlayers, NA_REAL), Ldown(ncanlayers, NA_REAL), Lnet(ncanlayers, NA_REAL);
   NumericVector tau(ncanlayers, NA_REAL), sumTauComp(ncanlayers, NA_REAL);
@@ -78,58 +30,146 @@ DataFrame communicationCanopyTurbulence(int ncanlayers) {
                                        Named("uw") = NumericVector(ncanlayers, NA_REAL));
   return(output);
 }
+
+const int SOILWBCOM_dZ_m = 0;
+const int SOILWBCOM_dZUp = 1;
+const int SOILWBCOM_dZDown = 2;
+const int SOILWBCOM_lambda = 3;
+const int SOILWBCOM_theta_micro = 4;
+const int SOILWBCOM_theta_b = 5;
+const int SOILWBCOM_theta_macro = 6;
+const int SOILWBCOM_theta_sat_fict = 7;
+const int SOILWBCOM_Ksat_b = 8;
+const int SOILWBCOM_Ksat_b_ms = 9;
+const int SOILWBCOM_Ksat = 10;
+const int SOILWBCOM_Ksat_ms = 11;
+const int SOILWBCOM_Psi = 12;
+const int SOILWBCOM_K = 13;
+const int SOILWBCOM_C = 14;
+const int SOILWBCOM_Psi_m = 15;
+const int SOILWBCOM_K_ms = 16;
+const int SOILWBCOM_Kbc = 17;
+const int SOILWBCOM_Kbc_ms = 18;
+const int SOILWBCOM_C_m = 19;
+const int SOILWBCOM_S_macro = 20;
+const int SOILWBCOM_e_macro = 21;
+const int SOILWBCOM_Kmacro_ms = 22;
+const int SOILWBCOM_waterFluidity = 23;
+const int SOILWBCOM_a = 24;
+const int SOILWBCOM_b = 25;
+const int SOILWBCOM_c = 26;
+const int SOILWBCOM_d = 27;
+const int SOILWBCOM_e = 28;
+const int SOILWBCOM_f = 29;
+const int SOILWBCOM_K_step_ms05 = 30;
+const int SOILWBCOM_C_step_m05 = 31;
+const int SOILWBCOM_C_step = 32;
+const int SOILWBCOM_C_step_m = 33;
+const int SOILWBCOM_K_step_ms = 34;
+const int SOILWBCOM_K_step = 35;
+const int SOILWBCOM_Psi_step = 36;
+const int SOILWBCOM_Psi_step_m = 37;
+const int SOILWBCOM_S_macro_step = 38;
+const int SOILWBCOM_Kmacro_step_ms = 39;
+const int SOILWBCOM_theta_macro_step = 40;
+const int SOILWBCOM_theta_micro_step = 41;
+const int SOILWBCOM_finalSourceSinks_m3s = 42;
+const int SOILWBCOM_capill_below = 43;
+const int SOILWBCOM_drain_above = 44;
+const int SOILWBCOM_drain_below = 45;
+const int SOILWBCOM_lateral_flows_step_mm = 46;
+
 List communicationSoilWaterBalance(int nlayers) {
   int ncol = 50;
   List out(ncol);
   CharacterVector colnames(ncol);
   for(int i = 0; i<ncol; i++) out[i] = NumericVector(nlayers, NA_REAL);
-  colnames[SOILCOM_dZ_m] = "dZ_m";
-  colnames[SOILCOM_dZUp] = "dZUp";
-  colnames[SOILCOM_dZDown] = "dZDown";
-  colnames[SOILCOM_lambda] = "lambda";
-  colnames[SOILCOM_theta_micro] = "theta_micro";
-  colnames[SOILCOM_theta_b] = "theta_b";
-  colnames[SOILCOM_theta_macro] = "theta_macro";
-  colnames[SOILCOM_theta_sat_fict] = "theta_sat_fict";
-  colnames[SOILCOM_Ksat_b] = "Ksat_b";
-  colnames[SOILCOM_Ksat_b_ms] = "Ksat_b_ms";
-  colnames[SOILCOM_Ksat] = "Ksat";
-  colnames[SOILCOM_Ksat_ms] = "Ksat_ms";
-  colnames[SOILCOM_Psi] = "Psi";
-  colnames[SOILCOM_K] = "K";
-  colnames[SOILCOM_C] = "C";
-  colnames[SOILCOM_Psi_m] = "Psi_m";
-  colnames[SOILCOM_K_ms] = "K_ms";
-  colnames[SOILCOM_Kbc] = "Kbc";
-  colnames[SOILCOM_Kbc_ms] = "Kbc_ms";
-  colnames[SOILCOM_C_m] = "C_m";
-  colnames[SOILCOM_S_macro] = "S_macro";
-  colnames[SOILCOM_e_macro] = "e_macro";
-  colnames[SOILCOM_Kmacro_ms] = "Kmacro_ms";
-  colnames[SOILCOM_waterFluidity] = "waterFluidity";
-  colnames[SOILCOM_a] = "a";
-  colnames[SOILCOM_b] = "b";
-  colnames[SOILCOM_c] = "c";
-  colnames[SOILCOM_d] = "d";
-  colnames[SOILCOM_e] = "e";
-  colnames[SOILCOM_f] = "f";
-  colnames[SOILCOM_K_step_ms05] = "K_step_ms05";
-  colnames[SOILCOM_C_step_m05] = "C_step_m05";
-  colnames[SOILCOM_C_step] = "C_step";
-  colnames[SOILCOM_C_step_m] = "C_step_m";
-  colnames[SOILCOM_K_step_ms] = "K_step_ms";
-  colnames[SOILCOM_K_step] = "K_step";
-  colnames[SOILCOM_Psi_step] = "Psi_step";
-  colnames[SOILCOM_Psi_step_m] = "Psi_step_m";
-  colnames[SOILCOM_S_macro_step] = "S_macro_step";
-  colnames[SOILCOM_Kmacro_step_ms] = "Kmacro_step_ms";
-  colnames[SOILCOM_theta_macro_step] = "theta_macro_step";
-  colnames[SOILCOM_theta_micro_step] = "theta_micro_step";
-  colnames[SOILCOM_finalSourceSinks_m3s] = "finalSourceSinks_m3s";
-  colnames[SOILCOM_capill_below] = "capill_below";
-  colnames[SOILCOM_drain_above] = "drain_above";
-  colnames[SOILCOM_drain_below] = "drain_below";
-  colnames[SOILCOM_lateral_flows_step_mm] = "lateral_flows_step_mm";
+  colnames[SOILWBCOM_dZ_m] = "dZ_m";
+  colnames[SOILWBCOM_dZUp] = "dZUp";
+  colnames[SOILWBCOM_dZDown] = "dZDown";
+  colnames[SOILWBCOM_lambda] = "lambda";
+  colnames[SOILWBCOM_theta_micro] = "theta_micro";
+  colnames[SOILWBCOM_theta_b] = "theta_b";
+  colnames[SOILWBCOM_theta_macro] = "theta_macro";
+  colnames[SOILWBCOM_theta_sat_fict] = "theta_sat_fict";
+  colnames[SOILWBCOM_Ksat_b] = "Ksat_b";
+  colnames[SOILWBCOM_Ksat_b_ms] = "Ksat_b_ms";
+  colnames[SOILWBCOM_Ksat] = "Ksat";
+  colnames[SOILWBCOM_Ksat_ms] = "Ksat_ms";
+  colnames[SOILWBCOM_Psi] = "Psi";
+  colnames[SOILWBCOM_K] = "K";
+  colnames[SOILWBCOM_C] = "C";
+  colnames[SOILWBCOM_Psi_m] = "Psi_m";
+  colnames[SOILWBCOM_K_ms] = "K_ms";
+  colnames[SOILWBCOM_Kbc] = "Kbc";
+  colnames[SOILWBCOM_Kbc_ms] = "Kbc_ms";
+  colnames[SOILWBCOM_C_m] = "C_m";
+  colnames[SOILWBCOM_S_macro] = "S_macro";
+  colnames[SOILWBCOM_e_macro] = "e_macro";
+  colnames[SOILWBCOM_Kmacro_ms] = "Kmacro_ms";
+  colnames[SOILWBCOM_waterFluidity] = "waterFluidity";
+  colnames[SOILWBCOM_a] = "a";
+  colnames[SOILWBCOM_b] = "b";
+  colnames[SOILWBCOM_c] = "c";
+  colnames[SOILWBCOM_d] = "d";
+  colnames[SOILWBCOM_e] = "e";
+  colnames[SOILWBCOM_f] = "f";
+  colnames[SOILWBCOM_K_step_ms05] = "K_step_ms05";
+  colnames[SOILWBCOM_C_step_m05] = "C_step_m05";
+  colnames[SOILWBCOM_C_step] = "C_step";
+  colnames[SOILWBCOM_C_step_m] = "C_step_m";
+  colnames[SOILWBCOM_K_step_ms] = "K_step_ms";
+  colnames[SOILWBCOM_K_step] = "K_step";
+  colnames[SOILWBCOM_Psi_step] = "Psi_step";
+  colnames[SOILWBCOM_Psi_step_m] = "Psi_step_m";
+  colnames[SOILWBCOM_S_macro_step] = "S_macro_step";
+  colnames[SOILWBCOM_Kmacro_step_ms] = "Kmacro_step_ms";
+  colnames[SOILWBCOM_theta_macro_step] = "theta_macro_step";
+  colnames[SOILWBCOM_theta_micro_step] = "theta_micro_step";
+  colnames[SOILWBCOM_finalSourceSinks_m3s] = "finalSourceSinks_m3s";
+  colnames[SOILWBCOM_capill_below] = "capill_below";
+  colnames[SOILWBCOM_drain_above] = "drain_above";
+  colnames[SOILWBCOM_drain_below] = "drain_below";
+  colnames[SOILWBCOM_lateral_flows_step_mm] = "lateral_flows_step_mm";
+  out.attr("names") = colnames;
+  return(out);
+}
+
+const int SOILEBCOM_dZ_m = 0;
+const int SOILEBCOM_dZUp = 1;
+const int SOILEBCOM_dZDown = 2;
+const int SOILEBCOM_Zup = 3;
+const int SOILEBCOM_Zdown = 4;
+const int SOILEBCOM_Zcent = 5;
+const int SOILEBCOM_a = 6;
+const int SOILEBCOM_b = 7;
+const int SOILEBCOM_c = 8;
+const int SOILEBCOM_d = 9;
+const int SOILEBCOM_e = 10;
+const int SOILEBCOM_f = 11;
+const int SOILEBCOM_k_up = 12;
+const int SOILEBCOM_k_down = 13;
+const int SOILEBCOM_tempch = 14;
+List communicationSoilEnergyBalance(int nlayers) {
+  int ncol = 15;
+  List out(ncol);
+  CharacterVector colnames(ncol);
+  for(int i = 0; i<ncol; i++) out[i] = NumericVector(nlayers, NA_REAL);
+  colnames[SOILEBCOM_dZ_m] = "dZ_m";
+  colnames[SOILEBCOM_dZUp] = "dZUp";
+  colnames[SOILEBCOM_dZDown] = "dZDown";
+  colnames[SOILEBCOM_Zup] = "Zup";
+  colnames[SOILEBCOM_Zdown] = "Zdown";
+  colnames[SOILEBCOM_Zcent] = "Zcent";
+  colnames[SOILEBCOM_a] = "a";
+  colnames[SOILEBCOM_b] = "b";
+  colnames[SOILEBCOM_c] = "c";
+  colnames[SOILEBCOM_d] = "d";
+  colnames[SOILEBCOM_e] = "e";
+  colnames[SOILEBCOM_f] = "f";
+  colnames[SOILEBCOM_k_up] = "k_up";
+  colnames[SOILEBCOM_k_down] = "k_down";
+  colnames[SOILEBCOM_tempch] = "tempch";
   out.attr("names") = colnames;
   return(out);
 }
@@ -786,8 +826,11 @@ List copyBasicTranspirationOutput(List btc, List x) {
   if(plantWaterPools) {
     for(int c=0;c<numCohorts;c++) {
       NumericMatrix ExtractionPoolsCohComm = ExtractionPoolsComm[c];
-      ExtractionPools[c] = copyNumericMatrix(ExtractionPoolsCohComm, numCohorts, nlayers); // this is final extraction of each cohort from each layer
+      NumericMatrix ExtractionPoolsCohComm_c = copyNumericMatrix(ExtractionPoolsCohComm, numCohorts, nlayers); // this is final extraction of each cohort from each layer
+      ExtractionPoolsCohComm_c.attr("dimnames") = List::create(above.attr("row.names"), seq(1,nlayers));
+      ExtractionPools[c] = ExtractionPoolsCohComm_c;
     }
+    ExtractionPools.attr("names") = above.attr("row.names");
   }
   
   NumericVector StandComm = btc["Stand"];
@@ -963,8 +1006,11 @@ List copyAdvancedTranspirationOutput(List atc, List x) {
   if(plantWaterPools) {
     for(int c=0;c<numCohorts;c++) {
       NumericMatrix ExtractionPoolsCohComm = ExtractionPoolsComm[c];
-      ExtractionPools[c] = copyNumericMatrix(ExtractionPoolsCohComm, numCohorts, nlayers); // this is final extraction of each cohort from each layer
+      NumericMatrix ExtractionPoolsCohComm_c = copyNumericMatrix(ExtractionPoolsCohComm, numCohorts, nlayers); // this is final extraction of each cohort from each layer
+      ExtractionPoolsCohComm_c.attr("dimnames") = List::create(above.attr("row.names"), seq(1,nlayers));
+      ExtractionPools[c] = ExtractionPoolsCohComm_c;
     }
+    ExtractionPools.attr("names") = above.attr("row.names");
   }
   
   NumericMatrix soilLayerExtractInstComm = atc["ExtractionInst"];
@@ -1399,12 +1445,14 @@ List copyModelOutput(List internalCommunication, List x, String model) {
 List generalCommunicationStructures(int numCohorts, int nlayers, int ncanlayers, int ntimesteps,
                                     String model) {
   List SWBcommunication = communicationSoilWaterBalance(nlayers);
+  List SEBcommunication = communicationSoilEnergyBalance(nlayers);
   List basicTranspirationOutput = basicTranspirationCommunicationOutput(numCohorts, nlayers);
   List advancedTranspirationOutput = advancedTranspirationCommunicationOutput(numCohorts, nlayers, ncanlayers, ntimesteps);
   List basicSPWBOutput = basicSPWBCommunicationOutput(basicTranspirationOutput, nlayers);
   List advancedSPWBOutput = advancedSPWBCommunicationOutput(advancedTranspirationOutput, nlayers);
   
   List ic = List::create(_["SWBcommunication"] = SWBcommunication,
+                         _["SEBcommunication"] = SEBcommunication,
                          _["basicTranspirationOutput"] = basicTranspirationOutput,
                          _["advancedTranspirationOutput"] = advancedTranspirationOutput,
                          _["basicSPWBOutput"] = basicSPWBOutput,
